@@ -41,8 +41,11 @@ class ParallelAtariEnv(ParallelEnv, EzPickle):
         max_cycles=100000,
         auto_rom_install_path=None,
     ):
-        """Frameskip should be either a tuple (indicating a random range to
-        choose from, with the top value exclude), or an int."""
+        """Initializes the `ParallelAtariEnv` class.
+
+        Frameskip should be either a tuple (indicating a random range to
+        choose from, with the top value exclude), or an int.
+        """
         EzPickle.__init__(
             self,
             game,
@@ -168,7 +171,7 @@ class ParallelAtariEnv(ParallelEnv, EzPickle):
             self.seed(seed=seed)
         self.ale.reset_game()
         self.agents = self.possible_agents[:]
-        self.dones = {agent: False for agent in self.possible_agents}
+        self.terminations = {agent: False for agent in self.possible_agents}
         self.frame = 0
 
         obs = self._observe()
@@ -205,12 +208,14 @@ class ParallelAtariEnv(ParallelEnv, EzPickle):
         actions = self.action_mapping[actions]
         rewards = self.ale.act(actions)
         self.frame += 1
-        if self.ale.game_over() or self.frame >= self.max_cycles:
-            dones = {agent: True for agent in self.agents}
+        truncations = {agent: self.frame >= self.max_cycles for agent in self.agents}
+
+        if self.ale.game_over():
+            terminations = {agent: True for agent in self.agents}
         else:
             lives = self.ale.allLives()
             # an inactive agent in ale gets a -1 life.
-            dones = {
+            terminations = {
                 agent: int(life) < 0
                 for agent, life in zip(self.possible_agents, lives)
                 if agent in self.agents
@@ -224,8 +229,8 @@ class ParallelAtariEnv(ParallelEnv, EzPickle):
             if agent in self.agents
         }
         infos = {agent: {} for agent in self.possible_agents if agent in self.agents}
-        self.agents = [agent for agent in self.agents if not dones[agent]]
-        return observations, rewards, dones, infos
+        self.agents = [agent for agent in self.agents if not terminations[agent]]
+        return observations, rewards, terminations, truncations, infos
 
     def render(self, mode="human"):
         (screen_width, screen_height) = self.ale.getScreenDims()
@@ -264,9 +269,12 @@ class ParallelAtariEnv(ParallelEnv, EzPickle):
             self._screen = None
 
     def clone_state(self):
-        """Clone emulator state w/o system state. Restoring this state will
-        *not* give an identical environment. For complete cloning and restoring
-        of the full state, see `{clone,restore}_full_state()`."""
+        """Clone emulator state w/o system state.
+
+        Restoring this state will *not* give an identical environment.
+        For complete cloning and restoring of the full state,
+        see `{clone,restore}_full_state()`.
+        """
         state_ref = self.ale.cloneState()
         state = self.ale.encodeState(state_ref)
         self.ale.deleteState(state_ref)
@@ -280,7 +288,9 @@ class ParallelAtariEnv(ParallelEnv, EzPickle):
 
     def clone_full_state(self):
         """Clone emulator state w/ system state including pseudorandomness.
-        Restoring this state will give an identical environment."""
+
+        Restoring this state will give an identical environment.
+        """
         state_ref = self.ale.cloneSystemState()
         state = self.ale.encodeState(state_ref)
         self.ale.deleteState(state_ref)
