@@ -1,3 +1,78 @@
+# noqa
+"""
+# Cooperative Pong
+
+```{figure} butterfly_cooperative_pong.gif
+:width: 200px
+:name: cooperative_pong
+```
+
+This environment is part of the <a href='..'>butterfly environments</a>. Please read that page first for general information.
+
+| Import               | `from pettingzoo.butterfly import cooperative_pong_v4` |
+|----------------------|--------------------------------------------------------|
+| Actions              | Discrete                                               |
+| Parallel API         | Yes                                                    |
+| Manual Control       | Yes                                                    |
+| Agents               | `agents= ['paddle_0', 'paddle_1']`                     |
+| Agents               | 2                                                      |
+| Action Shape         | Discrete(3)                                            |
+| Action Values        | [0, 1]                                                 |
+| Observation Shape    | (280, 480, 3)                                          |
+| Observation Values   | [0, 255]                                               |
+| State Shape          | (560, 960, 3)                                          |
+| State Values         | (0, 255)                                               |
+| Average Total Reward | -92.9                                                  |
+
+```{figure} ../../_static/img/aec/butterfly_cooperative_pong_aec.svg
+:width: 200px
+:name: cooperative_pong
+```
+
+Cooperative pong is a game of simple pong, where the objective is to keep the ball in play for the longest time. The game is over when the ball goes out of bounds from either the left or right edge of the screen. There are two agents (paddles), one that moves along the left edge and the other that
+moves along the right edge of the screen. All collisions of the ball are elastic. The ball always starts moving in a random direction from the center of the screen with each reset. To make learning a little more challenging, the right paddle is tiered cake-shaped by default.
+The observation space of each agent is its own half of the screen. There are two possible actions for the agents (_move up/down_). If the ball stays within bounds, each agent receives a reward of `max_reward / max_cycles` (default 0.11) at each timestep. Otherwise, each agent receives a reward of
+`off_screen_penalty` (default -10) and the game ends.
+
+
+### Manual Control
+
+Move the left paddle using the 'W' and 'S' keys. Move the right paddle using 'UP' and 'DOWN' arrow keys.
+
+### Arguments
+
+``` python
+cooperative_pong_v4.env(ball_speed=9, left_paddle_speed=12,
+right_paddle_speed=12, cake_paddle=True, max_cycles=900, bounce_randomness=False, max_reward=100, off_screen_penalty=-10)
+```
+
+`ball_speed`: Speed of ball (in pixels)
+
+`left_paddle_speed`: Speed of left paddle (in pixels)
+
+`right_paddle_speed`: Speed of right paddle (in pixels)
+
+`cake_paddle`: If True, the right paddle cakes the shape of a 4 tiered wedding cake
+
+`max_cycles`:  after max_cycles steps all agents will return done
+
+`bounce_randomness`: If True, each collision of the ball with the paddles adds a small random angle to the direction of the ball, with the speed of the ball remaining unchanged.
+
+`max_reward`:  Total reward given to each agent over max_cycles timesteps
+
+`off_screen_penalty`:  Negative reward penalty for each agent if the ball goes off the screen
+
+### Version History
+
+* v5: Fixed ball teleporting bugs
+* v4: Added max_reward and off_screen_penalty arguments and changed default, fixed glitch where ball would occasionally teleport, reward redesign (1.14.0)
+* v3: Change observation space to include entire screen (1.10.0)
+* v2: Misc fixes (1.4.0)
+* v1: Fixed bug in how `dones` were computed (1.3.1)
+* v0: Initial versions release (1.0.0)
+
+"""
+
 import gym
 import numpy as np
 import pygame
@@ -49,13 +124,13 @@ def get_valid_angle(randomizer):
 
     angle = 0
     while (
-        (angle > a1 and angle < b1)
-        or (angle > a2 and angle < b2)
-        or (angle > c1 and angle < d1)
+        (a1 < angle < b1)
+        or (a2 < angle < b2)
+        or (c1 < angle < d1)
         or (angle > c2)
         or (angle < d2)
     ):
-        angle = 2 * np.pi * randomizer.rand()
+        angle = 2 * np.pi * randomizer.random()
 
     return angle
 
@@ -140,7 +215,8 @@ class CooperativePong:
 
     def reinit(self):
         self.rewards = dict(zip(self.agents, [0.0] * len(self.agents)))
-        self.dones = dict(zip(self.agents, [False] * len(self.agents)))
+        self.terminations = dict(zip(self.agents, [False] * len(self.agents)))
+        self.truncations = dict(zip(self.agents, [False] * len(self.agents)))
         self.infos = dict(zip(self.agents, [{}] * len(self.agents)))
         self.score = 0
 
@@ -162,7 +238,8 @@ class CooperativePong:
         self.p0.speed = self.speed[1]
         self.p1.speed = self.speed[2]
 
-        self.done = False
+        self.terminate = False
+        self.truncate = False
 
         self.num_frames = 0
 
@@ -202,9 +279,7 @@ class CooperativePong:
         return observation
 
     def state(self):
-        """
-        Returns an observation of the global environment
-        """
+        """Returns an observation of the global environment."""
         state = pygame.surfarray.pixels3d(self.screen).copy()
         state = np.rot90(state, k=3)
         state = np.fliplr(state)
@@ -217,7 +292,6 @@ class CooperativePong:
         self.ball.draw(self.screen)
 
     def step(self, action, agent):
-
         # update p0, p1 accordingly
         # action: 0: do nothing,
         # action: 1: p[i] move up
@@ -228,28 +302,28 @@ class CooperativePong:
         elif agent == self.agents[1]:
             self.p1.update(self.area, action)
 
-            # do the rest if not done
-            if not self.done:
+            # do the rest if not terminated
+            if not self.terminate:
                 # update ball position
-                self.done = self.ball.update2(self.area, self.p0, self.p1)
+                self.terminate = self.ball.update2(self.area, self.p0, self.p1)
 
                 # do the miscellaneous stuff after the last agent has moved
                 # reward is the length of time ball is in play
                 reward = 0
                 # ball is out-of-bounds
-                if self.done:
+                if self.terminate:
                     reward = self.off_screen_penalty
                     self.score += reward
-                if not self.done:
+                if not self.terminate:
                     self.num_frames += 1
                     reward = self.max_reward / self.max_cycles
                     self.score += reward
-                    if self.num_frames == self.max_cycles:
-                        self.done = True
+                    self.truncate = self.num_frames >= self.max_cycles
 
                 for ag in self.agents:
                     self.rewards[ag] = reward
-                    self.dones[ag] = self.done
+                    self.terminations[ag] = self.terminate
+                    self.truncations[ag] = self.truncate
                     self.infos[ag] = {}
 
         if self.renderOn:
@@ -294,7 +368,8 @@ class raw_env(AECEnv, EzPickle):
         # dicts
         self.observations = {}
         self.rewards = self.env.rewards
-        self.dones = self.env.dones
+        self.terminations = self.env.terminations
+        self.truncations = self.env.truncations
         self.infos = self.env.infos
 
         self.score = self.env.score
@@ -320,7 +395,8 @@ class raw_env(AECEnv, EzPickle):
         self.agent_selection = self._agent_selector.reset()
         self.rewards = self.env.rewards
         self._cumulative_rewards = {a: 0 for a in self.agents}
-        self.dones = self.env.dones
+        self.terminations = self.env.terminations
+        self.truncations = self.env.truncations
         self.infos = self.env.infos
 
     def observe(self, agent):
@@ -338,8 +414,12 @@ class raw_env(AECEnv, EzPickle):
         return self.env.render(mode)
 
     def step(self, action):
-        if self.dones[self.agent_selection]:
-            return self._was_done_step(action)
+        if (
+            self.terminations[self.agent_selection]
+            or self.truncations[self.agent_selection]
+        ):
+            self._was_dead_step(action)
+            return
         agent = self.agent_selection
         if not self.action_spaces[agent].contains(action):
             raise Exception(
@@ -351,7 +431,8 @@ class raw_env(AECEnv, EzPickle):
         # select next agent and observe
         self.agent_selection = self._agent_selector.next()
         self.rewards = self.env.rewards
-        self.dones = self.env.dones
+        self.terminations = self.env.terminations
+        self.truncations = self.env.truncations
         self.infos = self.env.infos
 
         self.score = self.env.score
