@@ -1,3 +1,88 @@
+# noqa
+"""
+# Pistonball
+
+```{figure} butterfly_pistonball.gif
+:width: 200px
+:name: pistonball
+```
+
+This environment is part of the <a href='..'>butterfly environments</a>. Please read that page first for general information.
+
+| Import               | `from pettingzoo.butterfly import pistonball_v6`     |
+|----------------------|------------------------------------------------------|
+| Actions              | Either                                               |
+| Parallel API         | Yes                                                  |
+| Manual Control       | Yes                                                  |
+| Agents               | `agents= ['piston_0', 'piston_1', ..., 'piston_19']` |
+| Agents               | 20                                                   |
+| Action Shape         | (1,)                                                 |
+| Action Values        | [-1, 1]                                              |
+| Observation Shape    | (457, 120, 3)                                        |
+| Observation Values   | (0, 255)                                             |
+| State Shape          | (560, 880, 3)                                        |
+| State Values         | (0, 255)                                             |
+| Average Total Reward | -91.2                                                |
+
+```{figure} ../../_static/img/aec/butterfly_pistonball_aec.svg
+:width: 200px
+:name: pistonball
+```
+
+This is a simple physics based cooperative game where the goal is to move the ball to the left wall of the game border by activating the vertically moving pistons. Each piston agent's observation is an RGB image of the two pistons (or the wall) next to the agent and the space above them. Every
+piston can be acted on in any given time. The action space in discrete mode is 0 to move down, 1 to stay still, and 2 to move up. In continuous mode, the value in the range [-1, 1] is proportional to the amount that the pistons are raised or lowered by. Continuous actions are scaled by a factor
+of 4, so that in both the discrete and continuous action space, the action 1 will move a piston 4 pixels up, and -1 will move pistons 4 pixels down.
+
+Accordingly, pistons must learn highly coordinated emergent behavior to achieve an optimal policy for the environment. Each agent gets a reward that is a combination of how much the ball moved left overall and how much the ball moved left if it was close to the piston (i.e. movement the piston
+contributed to). A piston is considered close to the ball if it is directly below any part of the ball. Balancing the ratio between these local and global rewards appears to be critical to learning this environment, and as such is an environment parameter. The local reward applied is 0.5 times
+the change in the ball's x-position. Additionally, the global reward is change in x-position divided by the starting position, times 100, plus the `time_penalty` (default -0.1). For each piston, the reward is `local_ratio` * local_reward + (1-`local_ratio`) * global_reward. The local reward is
+applied to pistons surrounding the ball while the global reward is provided to all pistons.
+
+Pistonball uses the chipmunk physics engine, and are thus the physics are about as realistic as in the game Angry Birds.
+
+Keys *a* and *d* control which piston is selected to move (initially the rightmost piston is selected) and keys *w* and *s* move the piston in the vertical direction.
+
+
+### Arguments
+
+
+``` python
+pistonball_v6.env(n_pistons=20, time_penalty=-0.1, continuous=True,
+random_drop=True, random_rotate=True, ball_mass=0.75, ball_friction=0.3,
+ball_elasticity=1.5, max_cycles=125)
+```
+
+`n_pistons`: The number of pistons (agents) in the environment.
+
+`time_penalty`: Amount of reward added to each piston each time step. Higher values mean higher weight towards getting the ball across the screen to terminate the game.
+
+`continuous`:  If true, piston action is a real value between -1 and 1 which is added to the piston height. If False, then action is a discrete value to move a unit up or down.
+
+`random_drop`:  If True, ball will initially spawn in a random x value. If False, ball will always spawn at x=800
+
+`random_rotate`:  If True, ball will spawn with a random angular momentum
+
+`ball_mass`:  Sets the mass of the ball physics object
+
+`ball_friction`:  Sets the friction of the ball physics object
+
+`ball_elasticity`:  Sets the elasticity of the ball physics object
+
+`max_cycles`:  after max_cycles steps all agents will return done
+
+
+### Version History
+
+* v6: Fix ball bouncing off of left wall.
+* v5: Ball moving into the left column due to physics engine imprecision no longer gives additional reward
+* v4: Changed default arguments for `max_cycles` and `continuous`, bumped PyMunk version (1.6.0)
+* v3: Refactor, added number of pistons argument, minor visual changes (1.5.0)
+* v2: Misc fixes, bumped PyGame and PyMunk version (1.4.0)
+* v1: Fix to continuous mode (1.0.1)
+* v0: Initial versions release (1.0.0)
+
+"""
+
 import math
 
 import gym
@@ -159,7 +244,8 @@ class raw_env(AECEnv, EzPickle):
         self.ball_friction = ball_friction
         self.ball_elasticity = ball_elasticity
 
-        self.done = False
+        self.terminate = False
+        self.truncate = False
 
         self.pixels_per_position = 4
         self.n_piston_positions = 16
@@ -214,9 +300,7 @@ class raw_env(AECEnv, EzPickle):
         return observation
 
     def state(self):
-        """
-        Returns an observation of the global environment
-        """
+        """Returns an observation of the global environment."""
         state = pygame.surfarray.pixels3d(self.screen).copy()
         state = np.rot90(state, k=3)
         state = np.fliplr(state)
@@ -350,10 +434,10 @@ class raw_env(AECEnv, EzPickle):
         horizontal_offset_range = 30
         vertical_offset_range = 15
         if self.random_drop:
-            self.vertical_offset = self.np_random.random_integers(
+            self.vertical_offset = self.np_random.integers(
                 -vertical_offset_range, vertical_offset_range + 1
             )
-            self.horizontal_offset = self.np_random.random_integers(
+            self.horizontal_offset = self.np_random.integers(
                 -horizontal_offset_range, horizontal_offset_range + 1
             )
         ball_x = (
@@ -398,10 +482,12 @@ class raw_env(AECEnv, EzPickle):
         self.agent_selection = self._agent_selector.next()
 
         self.has_reset = True
-        self.done = False
+        self.terminate = False
+        self.truncate = False
         self.rewards = dict(zip(self.agents, [0 for _ in self.agents]))
         self._cumulative_rewards = dict(zip(self.agents, [0 for _ in self.agents]))
-        self.dones = dict(zip(self.agents, [False for _ in self.agents]))
+        self.terminations = dict(zip(self.agents, [False for _ in self.agents]))
+        self.truncations = dict(zip(self.agents, [False for _ in self.agents]))
         self.infos = dict(zip(self.agents, [{} for _ in self.agents]))
 
         self.frames = 0
@@ -523,8 +609,12 @@ class raw_env(AECEnv, EzPickle):
         )
 
     def step(self, action):
-        if self.dones[self.agent_selection]:
-            return self._was_done_step(action)
+        if (
+            self.terminations[self.agent_selection]
+            or self.truncations[self.agent_selection]
+        ):
+            self._was_dead_step(action)
+            return
 
         action = np.asarray(action)
         agent = self.agent_selection
@@ -544,14 +634,14 @@ class raw_env(AECEnv, EzPickle):
                 + self.ball.velocity[0] * self.dt
             )
             if ball_next_x <= self.wall_width + 1:
-                self.done = True
+                self.terminate = True
             # ensures that the ball can't pass through the wall
             ball_min_x = max(self.wall_width, ball_min_x)
             self.draw()
             local_reward = self.get_local_reward(self.lastX, ball_min_x)
             # Opposite order due to moving right to left
             global_reward = (100 / self.distance) * (self.lastX - ball_min_x)
-            if not self.done:
+            if not self.terminate:
                 global_reward += self.time_penalty
             total_reward = [
                 global_reward * (1 - self.local_ratio)
@@ -565,13 +655,17 @@ class raw_env(AECEnv, EzPickle):
         else:
             self._clear_rewards()
 
-        if self.frames >= self.max_cycles:
-            self.done = True
+        self.truncate = self.frames >= self.max_cycles
         # Clear the list of recent pistons for the next reward cycle
         if self.frames % self.recentFrameLimit == 0:
             self.recentPistons = set()
         if self._agent_selector.is_last():
-            self.dones = dict(zip(self.agents, [self.done for _ in self.agents]))
+            self.terminations = dict(
+                zip(self.agents, [self.terminate for _ in self.agents])
+            )
+            self.truncations = dict(
+                zip(self.agents, [self.truncate for _ in self.agents])
+            )
 
         self.agent_selection = self._agent_selector.next()
         self._cumulative_rewards[agent] = 0
