@@ -1,3 +1,67 @@
+# noqa
+"""
+# Connect Four
+
+```{figure} classic_connect_four.gif
+:width: 140px
+:name: connect_four
+```
+
+This environment is part of the <a href='..'>classic environments</a>. Please read that page first for general information.
+
+| Import             | `from pettingzoo.classic import connect_four_v3` |
+|--------------------|--------------------------------------------------|
+| Actions            | Discrete                                         |
+| Parallel API       | Yes                                              |
+| Manual Control     | No                                               |
+| Agents             | `agents= ['player_0', 'player_1']`               |
+| Agents             | 2                                                |
+| Action Shape       | (1,)                                             |
+| Action Values      | Discrete(7)                                      |
+| Observation Shape  | (6, 7, 2)                                        |
+| Observation Values | [0,1]                                            |
+
+```{figure} ../../_static/img/aec/classic_connect_four_aec.svg
+:width: 200px
+:name: connect_four
+```
+
+Connect Four is a 2-player turn based game, where players must connect four of their tokens vertically, horizontally or diagonally. The players drop their respective token in a column of a standing grid, where each token will fall until it reaches the bottom of the column or reaches an existing
+token. Players cannot place a token in a full column, and the game ends when either a player has made a sequence of 4 tokens, or when all 7 columns have been filled.
+
+### Observation Space
+
+The observation is a dictionary which contains an `'observation'` element which is the usual RL observation described below, and an  `'action_mask'` which holds the legal moves, described in the Legal Actions Mask section.
+
+
+The main observation space is 2 planes of a 6x7 grid. Each plane represents a specific agent's tokens, and each location in the grid represents the placement of the corresponding agent's token. 1 indicates that the agent has a token placed in that cell, and 0 indicates they do not have a token in
+that cell. A 0 means that either the cell is empty, or the other agent has a token in that cell.
+
+
+#### Legal Actions Mask
+
+The legal moves available to the current agent are found in the `action_mask` element of the dictionary observation. The `action_mask` is a binary vector where each index of the vector represents whether the action is legal or not. The `action_mask` will be all zeros for any agent except the one
+whose turn it is. Taking an illegal move ends the game with a reward of -1 for the illegally moving agent and a reward of 0 for all other agents.
+
+
+### Action Space
+
+The action space is the set of integers from 0 to 6 (inclusive), where the action represents which column a token should be dropped in.
+
+### Rewards
+
+If an agent successfully connects four of their tokens, they will be rewarded 1 point. At the same time, the opponent agent will be awarded -1 points. If the game ends in a draw, both players are rewarded 0.
+
+
+### Version History
+
+* v3: Fixed bug in arbitrary calls to observe() (1.8.0)
+* v2: Legal action mask in observation replaced illegal move list in infos (1.5.0)
+* v1: Bumped version of all environments due to adoption of new agent iteration scheme where all agents are iterated over after they are done (1.4.0)
+* v0: Initial versions release (1.0.0)
+
+"""
+
 import os
 
 import numpy as np
@@ -105,8 +169,11 @@ class raw_env(AECEnv):
 
     # action in this case is a value from 0 to 6 indicating position to move on the flat representation of the connect4 board
     def step(self, action):
-        if self.dones[self.agent_selection]:
-            return self._was_done_step(action)
+        if (
+            self.truncations[self.agent_selection]
+            or self.terminations[self.agent_selection]
+        ):
+            return self._was_dead_step(action)
         # assert valid move
         assert self.board[0:7][action] == 0, "played illegal move."
 
@@ -124,11 +191,11 @@ class raw_env(AECEnv):
         if winner:
             self.rewards[self.agent_selection] += 1
             self.rewards[next_agent] -= 1
-            self.dones = {i: True for i in self.agents}
+            self.terminations = {i: True for i in self.agents}
         # check if there is a tie
         elif all(x in [1, 2] for x in self.board):
             # once either play wins or there is a draw, game over, both players are done
-            self.dones = {i: True for i in self.agents}
+            self.terminations = {i: True for i in self.agents}
         else:
             # no winner yet
             self.agent_selection = next_agent
@@ -142,7 +209,8 @@ class raw_env(AECEnv):
         self.agents = self.possible_agents[:]
         self.rewards = {i: 0 for i in self.agents}
         self._cumulative_rewards = {name: 0 for name in self.agents}
-        self.dones = {i: False for i in self.agents}
+        self.terminations = {i: False for i in self.agents}
+        self.truncations = {i: False for i in self.agents}
         self.infos = {i: {} for i in self.agents}
 
         self._agent_selector = agent_selector(self.agents)
