@@ -1,3 +1,116 @@
+# noqa
+r"""
+# Go
+
+```{figure} classic_go.gif
+:width: 140px
+:name: go
+```
+
+This environment is part of the <a href='..'>classic environments</a>. Please read that page first for general information.
+
+| Import             | `from pettingzoo.classic import go_v5` |
+|--------------------|----------------------------------------|
+| Actions            | Discrete                               |
+| Parallel API       | Yes                                    |
+| Manual Control     | No                                     |
+| Agents             | `agents= ['black_0', 'white_0']`       |
+| Agents             | 2                                      |
+| Action Shape       | Discrete(362)                          |
+| Action Values      | Discrete(362)                          |
+| Observation Shape  | (19, 19, 3)                            |
+| Observation Values | [0, 1]                                 |
+
+```{figure} ../../_static/img/aec/classic_go_aec.svg
+:width: 200px
+:name: go
+```
+
+Go is a board game with 2 players, black and white. The black player starts by placing a black stone at an empty board intersection. The white player follows by placing a stone of their own, aiming to either surround more territory than their opponent or capture the opponent's stones. The game
+ends if both players sequentially decide to pass.
+
+Our implementation is a wrapper for [MiniGo](https://github.com/tensorflow/minigo).
+
+### Arguments
+
+Go takes two optional arguments that define the board size (int) and komi compensation points (float). The default values for the board size and komi are 19 and 7.5, respectively.
+
+``` python
+go_v5.env(board_size = 19, komi = 7.5)
+```
+
+`board_size`: The length of each size of the board.
+
+`komi`: The number of points given to white to compensate it for the disadvantage inherent to moving second. 7.5 is the standard value for Chinese tournament Go, but may not be perfectly balanced.
+
+### Observation Space
+
+The observation is a dictionary which contains an `'observation'` element which is the usual RL observation described below, and an  `'action_mask'` which holds the legal moves, described in the Legal Actions Mask section.
+
+
+The main observation shape is a function of the board size _N_ and has a shape of (N, N, 3). The first plane, (:, :, 0), represent the stones on the board for the current player while the second plane, (:, :, 1), encodes the stones of the opponent. The third plane, (:, :, 2), is all 1 if the
+current player is `black_0` or all 0 if the player is `white_0`. The state of the board is represented with the top left corner as (0, 0). For example, a (9, 9) board is
+```
+   0 1 2 3 4 5 6 7 8
+ 0 . . . . . . . . .  0
+ 1 . . . . . . . . .  1
+ 2 . . . . . . . . .  2
+ 3 . . . . . . . . .  3
+ 4 . . . . . . . . .  4
+ 5 . . . . . . . . .  5
+ 6 . . . . . . . . .  6
+ 7 . . . . . . . . .  7
+ 8 . . . . . . . . .  8
+   0 1 2 3 4 5 6 7 8
+```
+
+|  Plane  | Description                                               |
+|:-------:|-----------------------------------------------------------|
+|    0    | Current Player's stones<br>_'`0`: no stone, `1`: stone_   |
+|    1    | Opponent Player's stones<br>_'`0`: no stone, `1`: stone_  |
+|    2    | Player<br>_'`0`: white, `1`: black_                       |
+
+While rendering, the board coordinate system is [GTP](http://www.lysator.liu.se/~gunnar/gtp/).
+
+
+#### Legal Actions Mask
+
+The legal moves available to the current agent are found in the `action_mask` element of the dictionary observation. The `action_mask` is a binary vector where each index of the vector represents whether the action is legal or not. The `action_mask` will be all zeros for any agent except the one
+whose turn it is. Taking an illegal move ends the game with a reward of -1 for the illegally moving agent and a reward of 0 for all other agents.
+
+
+### Action Space
+
+Similar to the observation space, the action space is dependent on the board size _N_.
+
+|                          Action ID                           | Description                                                  |
+| :----------------------------------------------------------: | ------------------------------------------------------------ |
+| <img src="https://render.githubusercontent.com/render/math?math=0 \ldots (N-1)"> | Place a stone on the 1st row of the board.<br>_`0`: (0,0), `1`: (0,1), ..., `N-1`: (0,N-1)_ |
+| <img src="https://render.githubusercontent.com/render/math?math=N \ldots (2N- 1)"> | Place a stone on the 2nd row of the board.<br>_`N`: (1,0), `N+1`: (1,1), ..., `2N-1`: (1,N-1)_ |
+|                             ...                              | ...                                                          |
+| <img src="https://render.githubusercontent.com/render/math?math=N^2-N \ldots N^2-1"> | Place a stone on the Nth row of the board.<br>_`N^2-N`: (N-1,0), `N^2-N+1`: (N-1,1), ..., `N^2-1`: (N-1,N-1)_ |
+| <img src="https://render.githubusercontent.com/render/math?math=N^2"> | Pass                                                         |
+
+For example, you would use action `4` to place a stone on the board at the (0,3) location or action `N^2` to pass. You can transform a non-pass action `a` back into its 2D (x,y) coordinate by computing `(a//N, a%N)` The total action space is
+<img src="https://render.githubusercontent.com/render/math?math=N^2 %2B 1">.
+
+### Rewards
+
+| Winner | Loser |
+| :----: | :---: |
+| +1     | -1    |
+
+### Version History
+
+* v5: Changed observation space to proper AlphaZero style frame stacking (1.11.0)
+* v4: Fixed bug in how black and white pieces were saved in observation space (1.10.0)
+* v3: Fixed bug in arbitrary calls to observe() (1.8.0)
+* v2: Legal action mask in observation replaced illegal move list in infos (1.5.0)
+* v1: Bumped version of all environments due to adoption of new agent iteration scheme where all agents are iterated over after they are done (1.4.0)
+* v0: Initial versions release (1.0.0)
+
+"""
+
 import os
 
 import numpy as np
@@ -161,8 +274,11 @@ class raw_env(AECEnv):
         return {"observation": observation, "action_mask": action_mask}
 
     def step(self, action):
-        if self.dones[self.agent_selection]:
-            return self._was_done_step(action)
+        if (
+            self.terminations[self.agent_selection]
+            or self.truncations[self.agent_selection]
+        ):
+            return self._was_dead_step(action)
         self._go = self._go.play_move(coords.from_flat(action))
         self._last_obs = self.observe(self.agent_selection)
         current_agent_plane, opponent_agent_plane = self._encode_board_planes(
@@ -173,7 +289,9 @@ class raw_env(AECEnv):
         )
         next_player = self._agent_selector.next()
         if self._go.is_game_over():
-            self.dones = self._convert_to_dict([True for _ in range(self.num_agents)])
+            self.terminations = self._convert_to_dict(
+                [True for _ in range(self.num_agents)]
+            )
             self.rewards = self._convert_to_dict(
                 self._encode_rewards(self._go.result())
             )
@@ -196,7 +314,12 @@ class raw_env(AECEnv):
         self.agent_selection = self._agent_selector.reset()
         self._cumulative_rewards = self._convert_to_dict(np.array([0.0, 0.0]))
         self.rewards = self._convert_to_dict(np.array([0.0, 0.0]))
-        self.dones = self._convert_to_dict([False for _ in range(self.num_agents)])
+        self.terminations = self._convert_to_dict(
+            [False for _ in range(self.num_agents)]
+        )
+        self.truncations = self._convert_to_dict(
+            [False for _ in range(self.num_agents)]
+        )
         self.infos = self._convert_to_dict([{} for _ in range(self.num_agents)])
         self.next_legal_moves = self._encode_legal_actions(self._go.all_legal_moves())
         self._last_obs = self.observe(self.agents[0])
