@@ -1,3 +1,120 @@
+# noqa
+"""
+# Rock Paper Scissors
+
+```{figure} classic_rps.gif
+:width: 140px
+:name: rps
+```
+
+This environment is part of the <a href='..'>classic environments</a>. Please read that page first for general information.
+
+| Import             | `from pettingzoo.classic import rps_v2` |
+|--------------------|-----------------------------------------|
+| Actions            | Discrete                                |
+| Parallel API       | Yes                                     |
+| Manual Control     | No                                      |
+| Agents             | `agents= ['player_0', 'player_1']`      |
+| Agents             | 2                                       |
+| Action Shape       | Discrete(3)                             |
+| Action Values      | Discrete(3)                             |
+| Observation Shape  | Discrete(4)                             |
+| Observation Values | Discrete(4)                             |
+
+```{figure} ../../_static/img/aec/classic_rps_aec.svg
+:width: 200px
+:name: rps
+```
+
+Rock, Paper, Scissors is a 2-player hand game where each player chooses either rock, paper or scissors and reveals their choices simultaneously. If both players make the same choice, then it is a draw. However, if their choices are different, the winner is determined as follows: rock beats
+scissors, scissors beat paper, and paper beats rock.
+
+The game can be expanded to have extra actions by adding new action pairs. Adding the new actions in pairs allows for a more balanced game. This means that the final game will have an odd number of actions and each action wins over exactly half of the other actions while being defeated by the
+other half. The most common expansion of this game is [Rock, Paper, Scissors, Lizard, Spock](http://www.samkass.com/theories/RPSSL.html), in which only one extra action pair is added.
+
+### Arguments
+
+``` python
+rps_v2.env(num_actions=3, max_cycles=15)
+```
+
+`num_actions`:  number of actions applicable in the game. The default value is 3 for the game of Rock, Paper, Scissors. This argument must be an integer greater than 3 and with odd parity. If the value given is 5, the game is expanded to Rock, Paper, Scissors, Lizard, Spock.
+
+`max_cycles`:  after max_cycles steps all agents will return done.
+
+### Observation Space
+
+#### Rock, Paper, Scissors
+
+If 3 actions are required, the game played is the standard Rock, Paper, Scissors. The observation is the last opponent action and its space is a scalar value with 4 possible values. Since both players reveal their choices at the same time, the observation is None until both players have acted.
+Therefore, 3 represents no action taken yet. Rock is represented with 0, paper with 1 and scissors with 2.
+
+| Value  |  Observation |
+| :----: | :---------:  |
+| 0      | Rock         |
+| 1      | Paper        |
+| 2      | Scissors     |
+| 3      | None         |
+
+#### Expanded Game
+
+If the number of actions required in the game is greater than 3, the observation is still the last opponent action and its space is a scalar with 1 + n possible values, where n is the number of actions. The observation will as well be None until both players have acted and the largest possible
+scalar value for the space, 1 + n, represents no action taken yet. The additional actions are encoded in increasing order starting from the 0 Rock action. If 5 actions are required the game is expanded to Rock, Paper, Scissors, Lizard, Spock. The following table shows an example of an observation
+space with 7 possible actions.
+
+| Value  |  Observation |
+| :----: | :---------:  |
+| 0      | Rock         |
+| 1      | Paper        |
+| 2      | Scissors     |
+| 3      | Lizard       |
+| 4      | Spock        |
+| 5      | Action_6     |
+| 6      | Action_7     |
+| 7      | None         |
+
+### Action Space
+
+#### Rock, Paper, Scissors
+
+The action space is a scalar value with 3 possible values. The values are encoded as follows: Rock is 0, paper is 1 and scissors is 2.
+
+| Value  |  Action |
+| :----: | :---------:  |
+| 0      | Rock         |
+| 1      | Paper        |
+| 2      | Scissors     |
+
+#### Expanded Game
+
+The action space is a scalar value with n possible values, where n is the number of additional action pairs. The values for 7 possible actions are encoded as in the following table.
+
+| Value  |  Action |
+| :----: | :---------:  |
+| 0      | Rock         |
+| 1      | Paper        |
+| 2      | Scissors     |
+| 3      | Lizard       |
+| 4      | Spock        |
+| 5      | Action_6     |
+| 6      | Action_7     |
+
+### Rewards
+
+| Winner | Loser |
+| :----: | :---: |
+| +1     | -1    |
+
+If the game ends in a draw, both players will receive a reward of 0.
+
+### Version History
+
+* v2: Merge RPS and rock paper lizard scissors spock environments, add num_actions and max_cycles arguments (1.9.0)
+* v1: Bumped version of all environments due to adoption of new agent iteration scheme where all agents are iterated over after they are done (1.4.0)
+* v0: Initial versions release (1.0.0)
+
+"""
+
 import os
 
 import numpy as np
@@ -41,8 +158,10 @@ parallel_env = parallel_wrapper_fn(env)
 
 class raw_env(AECEnv):
     """Two-player environment for rock paper scissors.
+
     Expandable environment to rock paper scissors lizard spock action_6 action_7 ...
-    The observation is simply the last opponent action."""
+    The observation is simply the last opponent action.
+    """
 
     metadata = {
         "render_modes": ["human", "rgb_array"],
@@ -76,7 +195,6 @@ class raw_env(AECEnv):
         }
 
         self.screen = None
-        self.history = [0] * (2 * 5)
 
         self.reinit()
 
@@ -92,12 +210,15 @@ class raw_env(AECEnv):
         self.agent_selection = self._agent_selector.next()
         self.rewards = {agent: 0 for agent in self.agents}
         self._cumulative_rewards = {agent: 0 for agent in self.agents}
-        self.dones = {agent: False for agent in self.agents}
+        self.terminations = {agent: False for agent in self.agents}
+        self.truncations = {agent: False for agent in self.agents}
         self.infos = {agent: {} for agent in self.agents}
 
         self.state = {agent: self._none for agent in self.agents}
         self.observations = {agent: self._none for agent in self.agents}
 
+        self.history = [0] * (2 * 5)
+
         self.num_moves = 0
 
     def render(self, mode="human"):
@@ -291,10 +412,6 @@ class raw_env(AECEnv):
                             screen_height / 12,
                         ),
                     )
-                if self._moves[self.state[self.agents[1]]] != "None":
-                    self.history = [
-                        self._moves[self.state[self.agents[i]]]
-                    ] + self.history[:-1]
 
         if mode == "human":
             pygame.display.update()
@@ -316,8 +433,13 @@ class raw_env(AECEnv):
         self.reinit()
 
     def step(self, action):
-        if self.dones[self.agent_selection]:
-            return self._was_done_step(action)
+        if (
+            self.terminations[self.agent_selection]
+            or self.truncations[self.agent_selection]
+        ):
+            self._was_dead_step(action)
+            return
+
         agent = self.agent_selection
 
         self.state[self.agent_selection] = action
@@ -345,15 +467,19 @@ class raw_env(AECEnv):
 
             self.num_moves += 1
 
-            self.dones = {
+            self.truncations = {
                 agent: self.num_moves >= self.max_cycles for agent in self.agents
             }
-
-            # observe the current state
             for i in self.agents:
                 self.observations[i] = self.state[
                     self.agents[1 - self.agent_name_mapping[i]]
                 ]
+
+            # record history by pushing back
+            self.history[2:] = self.history[:-2]
+            self.history[0] = self.state[self.agents[0]]
+            self.history[1] = self.state[self.agents[1]]
+
         else:
             self.state[self.agents[1 - self.agent_name_mapping[agent]]] = self._none
 
