@@ -307,7 +307,8 @@ class MultiWalkerEnv:
         terrain_length=TERRAIN_LENGTH,
         max_cycles=500,
     ):
-        """
+        """Initializes the `MultiWalkerEnv` class.
+
         n_walkers: number of bipedal walkers in environment
         position_noise: noise applied to agent positional sensor observations
         angle_noise: noise applied to agent rotational sensor observations
@@ -319,7 +320,6 @@ class MultiWalkerEnv:
         terrain_length: length of terrain in number of steps
         max_cycles: after max_cycles steps all agents will return done
         """
-
         self.n_walkers = n_walkers
         self.position_noise = position_noise
         self.angle_noise = angle_noise
@@ -738,7 +738,7 @@ class MultiWalkerEnv:
                 y += velocity
 
             elif state == PIT and oneshot:
-                counter = self.np_random.random_integers(3, 5)
+                counter = self.np_random.integers(3, 5)
                 poly = [
                     (x, y),
                     (x + TERRAIN_STEP, y),
@@ -773,7 +773,7 @@ class MultiWalkerEnv:
                     y -= 4 * TERRAIN_STEP
 
             elif state == STUMP and oneshot:
-                counter = self.np_random.random_integers(1, 3)
+                counter = self.np_random.integers(1, 3)
                 poly = [
                     (x, y),
                     (x + counter * TERRAIN_STEP, y),
@@ -789,9 +789,9 @@ class MultiWalkerEnv:
                 self.terrain.append(t)
 
             elif state == STAIRS and oneshot:
-                stair_height = +1 if self.np_random.rand() > 0.5 else -1
-                stair_width = self.np_random.random_integers(4, 5)
-                stair_steps = self.np_random.random_integers(3, 5)
+                stair_height = +1 if self.np_random.random() > 0.5 else -1
+                stair_width = self.np_random.integers(4, 5)
+                stair_steps = self.np_random.integers(3, 5)
                 original_y = y
                 for s in range(stair_steps):
                     poly = [
@@ -830,11 +830,9 @@ class MultiWalkerEnv:
             self.terrain_y.append(y)
             counter -= 1
             if counter == 0:
-                counter = self.np_random.random_integers(
-                    TERRAIN_GRASS / 2, TERRAIN_GRASS
-                )
+                counter = self.np_random.integers(TERRAIN_GRASS / 2, TERRAIN_GRASS)
                 if state == GRASS and hardcore:
-                    state = self.np_random.random_integers(1, _STATES_)
+                    state = self.np_random.integers(1, _STATES_)
                     oneshot = True
                 else:
                     state = GRASS
