@@ -1,4 +1,5 @@
 import gym
+from gym.utils import seeding
 
 from pettingzoo import ParallelEnv
 from pettingzoo.utils import conversions, wrappers
@@ -45,8 +46,8 @@ class parallel_env(ParallelEnv):
 
     def add_type(self):
         type_id = len(self.types)
-        num_actions = self.np_random.random_integers(3, 10)
-        obs_size = self.np_random.random_integers(10, 50)
+        num_actions = self.np_random.integers(3, 10)
+        obs_size = self.np_random.integers(10, 50)
         obs_space = gym.spaces.Box(low=0, high=1, shape=(obs_size,))
         act_space = gym.spaces.Discrete(num_actions)
         new_type = f"type{type_id}"
@@ -66,7 +67,6 @@ class parallel_env(ParallelEnv):
     def reset(self, seed=None, return_info=False, options=None):
         if seed is not None:
             self.seed(seed=seed)
-        self.all_dones = {}
         self.agents = []
         self.num_steps = 0
         for i in range(5):
@@ -74,17 +74,18 @@ class parallel_env(ParallelEnv):
         return {agent: self.observe(agent) for agent in self.agents}
 
     def seed(self, seed=None):
-        self.np_random, _ = gym.utils.seeding.np_random(seed)
+        self.np_random, _ = seeding.np_random(seed)
 
     def step(self, actions):
-        done = self.num_steps >= self.max_cycles
+        truncated = self.num_steps >= self.max_cycles
         for agent in self.agents:
             assert agent in actions
-        all_dones = {agent: done for agent in self.agents}
-        if not done:
+        all_truncations = {agent: truncated for agent in self.agents}
+        all_terminations = {agent: False for agent in self.agents}
+        if not truncated:
             for i in range(6):
                 if self.np_random.random() < 0.1 and len(self.agents) >= 10:
-                    all_dones[self.np_random.choice(self.agents)] = True
+                    all_terminations[self.np_random.choice(self.agents)] = True
 
             for i in range(3):
                 if self.np_random.random() < 0.1:
@@ -94,14 +95,19 @@ class parallel_env(ParallelEnv):
                         type = self.np_random.choice(self.types)
 
                     new_agent = self.add_agent(type)
-                    all_dones[new_agent] = False
+                    all_terminations[new_agent] = False
+                    all_truncations[new_agent] = False
 
         all_infos = {agent: {} for agent in self.agents}
         all_rewards = {agent: 0 for agent in self.agents}
         all_rewards[self.np_random.choice(self.agents)] = 1
         all_observes = {agent: self.observe(agent) for agent in self.agents}
-        self.agents = [agent for agent in self.agents if not all_dones[agent]]
-        return all_observes, all_rewards, all_dones, all_infos
+        self.agents = [
+            agent
+            for agent in self.agents
+            if not (all_truncations[agent] or all_terminations[agent])
+        ]
+        return all_observes, all_rewards, all_terminations, all_truncations, all_infos
 
     def render(self, mode="human"):
         print(self.agents)
