@@ -23,7 +23,7 @@ def test_state_space(env):
             )
         if np.any(np.equal(env.state_space.high, np.inf)):
             warnings.warn(
-                "Environment's maxmimum state space value is infinity. This is probably too high"
+                "Environment's maximum state space value is infinity. This is probably too high"
             )
         if np.any(np.equal(env.state_space.low, env.state_space.high)):
             warnings.warn(
@@ -47,8 +47,8 @@ def test_state(env, num_cycles):
     env.reset()
     state_0 = env.state()
     for agent in env.agent_iter(env.num_agents * num_cycles):
-        observation, reward, done, info = env.last(observe=False)
-        if done:
+        observation, reward, terminated, truncated, info = env.last(observe=False)
+        if terminated or truncated:
             action = None
         else:
             action = env.action_space(agent).sample()
