@@ -4,17 +4,17 @@ import numpy as np
 
 
 def average_total_reward(env, max_episodes=100, max_steps=10000000000):
-    """
-    Runs an env object with random actions until either max_episodes or
-    max_steps is reached. Calculates the average total reward over the
-    episodes.
+    """Calculates the average total reward over the episodes.
 
+    Runs an env object with random actions until either max_episodes or
+    max_steps is reached.
     Reward is summed across all agents, making it unsuited for use in zero-sum
     games.
     """
     total_reward = 0
     total_steps = 0
     done = False
+    num_episodes = 0
 
     for episode in range(max_episodes):
         if total_steps >= max_steps:
