@@ -4,8 +4,8 @@ from .base import BaseWrapper
 
 
 class AssertOutOfBoundsWrapper(BaseWrapper):
-    """
-    this wrapper crashes for out of bounds actions
+    """This wrapper crashes for out of bounds actions.
+
     Should be used for Discrete spaces
     """
 
@@ -18,7 +18,11 @@ class AssertOutOfBoundsWrapper(BaseWrapper):
 
     def step(self, action):
         assert (
-            action is None and self.dones[self.agent_selection]
+            action is None
+            and (
+                self.terminations[self.agent_selection]
+                or self.truncations[self.agent_selection]
+            )
         ) or self.action_space(self.agent_selection).contains(
             action
         ), "action is not in action space"
