@@ -4,9 +4,9 @@ from pettingzoo.utils.env import AECEnv
 
 
 class BaseWrapper(AECEnv):
-    """
-    Creates a wrapper around `env` parameter. Extend this class
-    to create a useful wrapper.
+    """Creates a wrapper around `env` parameter.
+
+    Extend this class to create a useful wrapper.
     """
 
     def __init__(self, env):
@@ -86,7 +86,8 @@ class BaseWrapper(AECEnv):
 
         self.agent_selection = self.env.agent_selection
         self.rewards = self.env.rewards
-        self.dones = self.env.dones
+        self.terminations = self.env.terminations
+        self.truncations = self.env.truncations
         self.infos = self.env.infos
         self.agents = self.env.agents
         self._cumulative_rewards = self.env._cumulative_rewards
@@ -102,13 +103,12 @@ class BaseWrapper(AECEnv):
 
         self.agent_selection = self.env.agent_selection
         self.rewards = self.env.rewards
-        self.dones = self.env.dones
+        self.terminations = self.env.terminations
+        self.truncations = self.env.truncations
         self.infos = self.env.infos
         self.agents = self.env.agents
         self._cumulative_rewards = self.env._cumulative_rewards
 
     def __str__(self):
-        """
-        returns a name which looks like: "max_observation<space_invaders_v1>"
-        """
+        """Returns a name which looks like: "max_observation<space_invaders_v1>"."""
         return f"{type(self).__name__}<{str(self.env)}>"
