@@ -6,9 +6,7 @@ from .base import BaseWrapper
 
 
 class ClipOutOfBoundsWrapper(BaseWrapper):
-    """
-    this wrapper crops out of bounds actions for Box spaces
-    """
+    """This wrapper crops out of bounds actions for Box spaces."""
 
     def __init__(self, env):
         super().__init__(env)
@@ -20,7 +18,11 @@ class ClipOutOfBoundsWrapper(BaseWrapper):
     def step(self, action):
         space = self.action_space(self.agent_selection)
         if not (
-            action is None and self.dones[self.agent_selection]
+            action is None
+            and (
+                self.terminations[self.agent_selection]
+                or self.truncations[self.agent_selection]
+            )
         ) and not space.contains(action):
             assert (
                 space.shape == action.shape
